REFUNDED_CAP_COL = 'refunded_cap'
INTERSET_COL = 'interset'
CAP_COL = 'cap'
YEAR_COL = 'annees'
MONTHLY_COL = 'mensualites'
INS_T_COL = 'assur Tom'
INS_M_COL = 'assur Mel'
INS_ALL_COL = 'assur tot'
MONTHLY_INS_COL = 'mensu avc assur'

ALL_COLS = [YEAR_COL, MONTHLY_COL, INS_ALL_COL, MONTHLY_INS_COL, REFUNDED_CAP_COL, INTERSET_COL, CAP_COL]

INS_T_ACT_COL = 'assur Tom reel'
INS_M_ACT_COL = 'assur Mel reel'
INS_ALL_ACT_COL = 'assur tot reel'

COSTS_COL = 'costs'
INS_RATES_COL = 'ins_rates'
